@@ -35,5 +35,5 @@ class DenyInsertUpdateDateTime:
 class BaseValidatorsMixin(OwnerNotRequiredMixin, CheckUnknownFieldsMixin, DenyOwnerOverrideMixin, DenyInsertUpdateDateTime):
     _id = fields.String(required=False)
 
-    insert_timestamp = fields.Str(required=False)
-    update_timestamp = fields.Str(required=False)
\ No newline at end of file
+    insert_timestamp = fields.Int(required=False)
+    update_timestamp = fields.Int(required=False)
\ No newline at end of file
